@@ -5,8 +5,8 @@ use warnings;
 use Devel::Trace::Subs qw(install_trace);
 
 my %params = (
-#    file => '../devel-examine-subs/lib/Devel/Examine',
-    file => 'Devel::Examine::Subs',
+    file => '../test/lib/Devel/Examine',
+#    file => 'Devel::Examine::Subs',
 );
 
 install_trace(%params);
